(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     72651,       1842]
NotebookOptionsPosition[     69450,       1737]
NotebookOutlinePosition[     69888,       1754]
CellTagsIndexPosition[     69845,       1751]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["ScannerS Input file generator", "Title",
 CellChangeTimes->{{3.534139124702258*^9, 3.534139140894373*^9}, {
  3.5431344646773643`*^9, 3.543134466549079*^9}}],

Cell[TextData[{
 "This notebook allows the user to generate an input file for the ScannerS \
program, given a polynomial expression for the scalar potential and the \
number of real components that compose the various scalar multiplets. The \
first section needs to be edited for each particular model and the key \
information to provide is: i)The number of real components defining the \
variable Nreal and the number of couplings Ncoup ii) A fully expanded \
expression for the scalar potential decomposed in Nreal scalars organised in \
an array \[Phi][i] with i=1...Nreal, and in terms of the couplings \
\[Lambda][j], j=1...Ncoup and respective ranges for the scan iii) The path \
and name where to save the ScannerS input file\n\nSome other switches are \
also provided to control (for example) user defined parametrizations.\n\n",
 StyleBox["The list of quantities that must be defined is",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 " (descriptions below in comments of each variable):\n-> ",
 StyleBox["Nreal ",
  FontWeight->"Bold"],
 "\n-> ",
 StyleBox["Ncoup ",
  FontWeight->"Bold"],
 "\n-> ",
 StyleBox["NparamsVEVs\n-> NparamsMixing",
  FontWeight->"Bold"],
 "\n->",
 StyleBox[" NparamsMassL",
  FontWeight->"Bold"],
 "\n->",
 StyleBox[" Vscalar",
  FontWeight->"Bold"],
 "\n-> ",
 StyleBox["\[Phi]Min[i] ",
  FontWeight->"Bold"],
 " and ",
 StyleBox["\[Phi]Max[i]",
  FontWeight->"Bold"],
 " (i=0, ... ,Nreal-1 )\n-> ",
 StyleBox["\[Phi]ParMin[j]",
  FontWeight->"Bold"],
 "  and ",
 StyleBox["\[Phi]ParMax[j]",
  FontWeight->"Bold"],
 " (j=0, ... , NparamsVEVs-1 ) --- OPTIONAL (only if  NparamsVEVs>0)\n-> ",
 StyleBox["MixParMin[j] ",
  FontWeight->"Bold"],
 " and ",
 StyleBox["MixParMax[j]",
  FontWeight->"Bold"],
 " (j=0, ... , NparamsMixing-1 ) --- OPTIONAL (only if  NparamsMixing>0)\n-> ",
 StyleBox["\[Lambda]Min[k]",
  FontWeight->"Bold"],
 " and ",
 StyleBox["\[Lambda]Max[k]",
  FontWeight->"Bold"],
 " (k=0, ... , Ncoup-1)\n-> ",
 StyleBox["massmin[i]",
  FontWeight->"Bold"],
 "  and ",
 StyleBox["massmax[i]",
  FontWeight->"Bold"],
 " (i=0, ... ,Nreal-1 )\n-> ",
 StyleBox["MLParMin[n]",
  FontWeight->"Bold"],
 " and ",
 StyleBox["MLParMax[n]",
  FontWeight->"Bold"],
 " (n=0, ... , NparamsMassL-1) --- OPTIONAL (only if  NparamsMassL>0)\n-> ",
 StyleBox["InputFileName",
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{{3.534139153767818*^9, 3.5341394862417727`*^9}, {
   3.534140210077389*^9, 3.534140226239519*^9}, {3.534140287550242*^9, 
   3.534140364231353*^9}, {3.534140503439558*^9, 3.534140510794918*^9}, {
   3.5341447449859133`*^9, 3.534144752493857*^9}, {3.585478586019114*^9, 
   3.585478638814126*^9}, {3.585479527066248*^9, 3.585479605113472*^9}, {
   3.585482684075522*^9, 3.5854827830035458`*^9}, {3.585483502866034*^9, 
   3.585483773446186*^9}, {3.5854838073725777`*^9, 3.585483846521552*^9}, {
   3.5854839707672043`*^9, 3.58548400564085*^9}, {3.585484332685555*^9, 
   3.585484357047865*^9}, {3.585499880744681*^9, 3.585499906893263*^9}, {
   3.585500280273981*^9, 3.5855002806999063`*^9}, {3.585500334549485*^9, 
   3.5855003604343967`*^9}, 3.585500400530427*^9, {3.585500459233739*^9, 
   3.58550049324888*^9}, {3.585500533622078*^9, 3.585500543706848*^9}}],

Cell[CellGroupData[{

Cell["User defined expressions (To be edited by the user)", "Section",
 CellChangeTimes->{{3.534139699550837*^9, 3.534139703527507*^9}, {
  3.534152333239427*^9, 3.534152342256386*^9}}],

Cell[CellGroupData[{

Cell["Internal switches to control model and run", "Subsection",
 CellChangeTimes->{{3.5341400938604507`*^9, 3.534140099025897*^9}, {
  3.534140230565733*^9, 3.5341402323063917`*^9}, {3.585478545532669*^9, 
  3.5854785537190104`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Nreal", "=", "8"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"This", " ", "is", " ", "the", " ", "number", " ", "of"}], ",", 
    " ", "real", ",", " ", 
    RowBox[{"degrees", " ", "of", " ", 
     RowBox[{"freedom", "/", "fields"}]}]}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.534140001122467*^9, 3.53414002733514*^9}, {
   3.535107537502141*^9, 3.535107539298517*^9}, {3.549553504718693*^9, 
   3.54955350476075*^9}, {3.5496185414294558`*^9, 3.5496185415172157`*^9}, {
   3.583119945326511*^9, 3.583119960657104*^9}, 3.583126321533564*^9, {
   3.585478556417615*^9, 3.585478580868178*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Ncoup", "=", "8"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"This", " ", "is", " ", "the", " ", "number", " ", "of"}], ",", 
    " ", "real", ",", " ", 
    RowBox[{"couplings", " ", "in", " ", "the", " ", "potential"}]}], " ", 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.534140236071824*^9, 3.534140262292913*^9}, {
   3.535107550204233*^9, 3.535107551069602*^9}, {3.535115146643319*^9, 
   3.535115148652267*^9}, {3.537020277634386*^9, 3.537020277848011*^9}, {
   3.549618546323228*^9, 3.549618571938922*^9}, {3.549621056195997*^9, 
   3.549621056242008*^9}, {3.549621150023106*^9, 3.549621173023985*^9}, {
   3.549638953324149*^9, 3.549638953615148*^9}, {3.5497100916771917`*^9, 
   3.549710092642866*^9}, {3.583071724970649*^9, 3.583071726395556*^9}, 
   3.583126323095623*^9, {3.585478641804598*^9, 3.585478662795334*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"NparamsVEVs", "=", "1"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "This", " ", "is", " ", "active", "  ", "only", " ", "if", " ", "larger",
       " ", "than", " ", "zero", " ", 
      RowBox[{
       RowBox[{"(", "0", ")"}], ".", " ", "To"}], " ", "de"}], "-", 
     RowBox[{"activate", " ", "set", " ", "to", " ", 
      RowBox[{"zero", ".", " ", "This"}], " ", "integer", " ", "is", " ", 
      "the", " ", "number", " ", "of", " ", "real", " ", "parameters", " ", 
      "used", " ", "to", " ", "re"}], "-", 
     RowBox[{"parametrize", " ", "the", " ", "VEVs", " ", "being", " ", 
      RowBox[{"generated", ".", " ", "If"}], " ", "off", " ", 
      RowBox[{"(", "0", ")"}]}]}], ",", " ", 
    RowBox[{
    "the", " ", "VEVs", " ", "are", " ", "generated", " ", "uniformly", " ", 
     "in", " ", "a", " ", "hypercubic", " ", "box", " ", 
     RowBox[{"(", 
      RowBox[{
      "according", " ", "to", " ", "the", " ", "ranges", " ", "defined", " ", 
       "in", " ", "the", " ", "section", " ", "\"\<Ranges\>\"", " ", 
       "below"}], ")"}]}], ",", " ", 
    RowBox[{
     RowBox[{"otherwise", " ", "the", " ", "user"}], "-", 
     RowBox[{
     "defined", " ", "function", " ", "\"\<MyPhiParametrization\>\"", " ", 
      "in", " ", 
      RowBox[{"ScannerSUser", ".", "cpp"}], " ", "is", " ", "used"}]}]}], 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.5830717287197104`*^9, 3.5830717580937147`*^9}, {
   3.583071840934731*^9, 3.5830718548112097`*^9}, 3.583119290786797*^9, {
   3.583119758713336*^9, 3.5831197587669573`*^9}, 3.5831253374820137`*^9, 
   3.583126325985382*^9, {3.5831403702663116`*^9, 3.583140371724491*^9}, {
   3.583140438864959*^9, 3.5831404430164022`*^9}, {3.583140514757739*^9, 
   3.5831405154071712`*^9}, {3.5831415397580347`*^9, 3.583141540463245*^9}, {
   3.583141895670452*^9, 3.5831419017159443`*^9}, {3.583758406962304*^9, 
   3.5837584344579268`*^9}, 3.5837585071671047`*^9, {3.5854786707028017`*^9, 
   3.585478831309935*^9}, 3.585478893914448*^9, {3.585479014687324*^9, 
   3.585479043291883*^9}, {3.585479136162771*^9, 3.585479145000149*^9}, {
   3.585500078912011*^9, 3.585500082639312*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"NparamsMixing", "=", "0"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "This", " ", "is", " ", "active", "  ", "only", " ", "if", " ", "larger",
       " ", "than", " ", "zero", " ", 
      RowBox[{
       RowBox[{"(", "0", ")"}], ".", " ", "To"}], " ", "de"}], "-", 
     RowBox[{"activate", " ", "set", " ", "to", " ", 
      RowBox[{"zero", ".", " ", "This"}], " ", "integer", " ", "is", " ", 
      "the", " ", "number", " ", "of", " ", "real", " ", "parameters", " ", 
      "used", " ", "to", " ", "parametrize", " ", "the", " ", "mixing", " ", 
      "matrix", " ", "through", " ", "a", " ", "defined", " ", "function", 
      " ", "\"\<MyCoupMassRelations\>\"", " ", "in", " ", 
      RowBox[{"ScannerSUser", ".", "cpp", ".", " ", "If"}], " ", "off", " ", 
      RowBox[{"(", "0", ")"}]}]}], ",", 
    RowBox[{
    "the", " ", "mixing", " ", "matrix", " ", "is", " ", "generated", " ", 
     "with", " ", "uniformly", " ", "probability", " ", 
     RowBox[{"(", 
      RowBox[{
      "with", " ", "respect", " ", "to", " ", "the", " ", "H\[ADoubleDot]ar", 
       " ", "measure"}], ")"}]}], ",", " ", 
    RowBox[{"otherwise", " ", "the"}], ",", " ", 
    RowBox[{"user", "-", "defined"}], ",", " ", 
    RowBox[{"function", " ", "\"\<MyCoupMassRelations\>\"", " ", "in", " ", 
     RowBox[{"ScannerSUser", ".", "cpp"}], " ", "is", " ", 
     RowBox[{"used", ".", " ", "Note"}], " ", "that", " ", "such", " ", 
     "user", " ", "defined", " ", "function", " ", "can", " ", "depend", " ", 
     "of", " ", "the", " ", "VEV", " ", "values", " ", "or", " ", 
     "parameters"}]}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.585479369598381*^9, 3.585479467597618*^9}, {
   3.585485066284457*^9, 3.585485122966332*^9}, {3.585485199168365*^9, 
   3.585485199442231*^9}, 3.5854854228579197`*^9, {3.585495474345923*^9, 
   3.5854954760813427`*^9}, {3.585495509304283*^9, 3.585495509595584*^9}, {
   3.585495629862289*^9, 3.585495630128745*^9}, {3.585499914078368*^9, 
   3.585500046258539*^9}, {3.585500095253937*^9, 3.5855001662337313`*^9}, {
   3.585501078206011*^9, 3.585501078303528*^9}, {3.5855023471534023`*^9, 
   3.585502347376927*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"NparamsMassL", " ", "=", " ", "0"}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "This", " ", "is", " ", "active", "  ", "only", " ", "if", " ", "larger",
       " ", "than", " ", "zero", " ", 
      RowBox[{
       RowBox[{"(", "0", ")"}], ".", " ", "To"}], " ", "de"}], "-", 
     RowBox[{"activate", " ", "set", " ", "to", " ", "zero", " ", 
      RowBox[{
       RowBox[{"(", "0", ")"}], ".", " ", "This"}], " ", "integer", " ", "is",
       " ", "the", " ", "number", " ", "of", " ", "real", " ", "parameters", 
      " ", "used", " ", "to", " ", "parametrize", " ", "a", " ", "relation", 
      " ", "among", " ", "the", " ", "last", " ", "generated", " ", "Masses", 
      " ", "and", " ", "couplings", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
        "see", " ", "user", " ", "defined", " ", "function", " ", 
         "\"\<MyCoupMassRelations\>\"", " ", "in", " ", 
         RowBox[{"ScannerSUser", ".", "cpp"}]}], ")"}], ".", " ", "If"}], " ",
       "off", " ", 
      RowBox[{"(", "0", ")"}]}]}], ",", " ", 
    RowBox[{
    "the", " ", "last", " ", "independent", " ", "masses", " ", "and", " ", 
     "couplings", " ", "are", " ", "generated", " ", "in", " ", "a", " ", 
     "hypercubic", " ", "box", " ", 
     RowBox[{"(", 
      RowBox[{
      "according", " ", "to", " ", "the", " ", "ranges", " ", "defined", " ", 
       "in", " ", "the", " ", "section", " ", "\"\<Ranges\>\"", " ", 
       "below"}], ")"}]}], ",", " ", 
    RowBox[{"otherwise", " ", "the"}], ",", " ", 
    RowBox[{"user", "-", "defined"}], ",", " ", 
    RowBox[{"function", " ", "\"\<MyCoupMassRelations\>\"", " ", "in", " ", 
     RowBox[{"ScannerSUser", ".", "cpp"}], " ", "is", " ", 
     RowBox[{"used", ".", " ", "Note"}], " ", "that", " ", "this", " ", 
     "user", " ", "defined", " ", "function", " ", "can", " ", "depend", " ", 
     "on", " ", "VEVs", " ", "and", " ", "Mixings", " ", "or", " ", 
     "corresponding", " ", 
     RowBox[{"parameters", "."}]}]}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.5837583148484592`*^9, 3.583758386966074*^9}, {
   3.583758420229499*^9, 3.583758435914453*^9}, {3.5837643032246428`*^9, 
   3.5837643034445667`*^9}, {3.583764495911582*^9, 3.5837644967409887`*^9}, {
   3.5837653238688374`*^9, 3.583765324067956*^9}, 3.585478843101055*^9, 
   3.585478929658777*^9, {3.585478981298455*^9, 3.585479011929343*^9}, {
   3.5854790644483423`*^9, 3.585479153117096*^9}, {3.585500062479171*^9, 
   3.58550007217819*^9}, {3.58550017750421*^9, 3.585500209571487*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Polynomial Expression for the potential in terms of \[Phi][i] and \[Lambda][j]\
\>", "Subsection",
 CellChangeTimes->{{3.534140137138444*^9, 3.534140159456518*^9}, {
  3.534140270579125*^9, 3.534140272374899*^9}, {3.534140376055615*^9, 
  3.534140382933145*^9}, {3.534140544931155*^9, 3.5341405499086857`*^9}}],

Cell["\<\
This first lines are just auxiliary expressions that are optional. What is \
important is that the Vscalar expression is defined correctly some lines \
below!\
\>", "Text",
 CellChangeTimes->{{3.585479652906949*^9, 3.585479713674541*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CapitalPhi]1", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Phi]", "[", "0", "]"}], "+", 
       RowBox[{"I", " ", 
        RowBox[{"\[Phi]", "[", "1", "]"}]}]}], ")"}], "/", 
     RowBox[{"Sqrt", "[", "2", "]"}]}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Phi]", "[", "2", "]"}], "+", 
       RowBox[{"I", " ", 
        RowBox[{"\[Phi]", "[", "3", "]"}]}]}], ")"}], "/", 
     RowBox[{"Sqrt", "[", "2", "]"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.535109196021991*^9, 3.535109196373943*^9}, {
  3.535109520871797*^9, 3.535109528823069*^9}, {3.535110070367919*^9, 
  3.535110071019047*^9}, {3.535111702122002*^9, 3.535111702444166*^9}, {
  3.549553587505783*^9, 3.549553597393755*^9}, {3.5496187395042467`*^9, 
  3.5496187613882113`*^9}, {3.565089691920523*^9, 3.565089706237021*^9}, {
  3.565089750073328*^9, 3.565089751799815*^9}, {3.56509265539555*^9, 
  3.565092659255678*^9}, {3.570780201546114*^9, 3.570780246360174*^9}, {
  3.58312642496203*^9, 3.583126433395574*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"\[Phi]", "[", "0", "]"}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"\[Phi]", "[", "1", "]"}]}]}], 
    SqrtBox["2"]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"\[Phi]", "[", "2", "]"}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"\[Phi]", "[", "3", "]"}]}]}], 
    SqrtBox["2"]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.570347593155091*^9, 3.570780234626966*^9, 3.570780275568789*^9, 
   3.570782347770499*^9, 3.570801957205337*^9, 3.57080200088017*^9, 
   3.570802122705267*^9, 3.570802161340332*^9, 3.570802221310916*^9, 
   3.570802303044646*^9, 3.573370250600205*^9, {3.577100674377851*^9, 
   3.577100683118408*^9}, 3.577100911586241*^9, 3.577102192539304*^9, 
   3.5831268402225933`*^9, 3.5831271776408167`*^9, 3.5831403762780447`*^9, 
   3.583140445930541*^9, 3.583140517702251*^9, 3.583141544631421*^9, 
   3.583141904318516*^9, 3.5831436207281103`*^9, 3.583143650747457*^9, 
   3.583758931657578*^9, 3.583764307231513*^9, 3.583764500057564*^9, 
   3.583765327523185*^9, {3.5854800403238163`*^9, 3.585480057166016*^9}, {
   3.5854801491305437`*^9, 3.585480158899188*^9}, {3.585480200166749*^9, 
   3.585480208771296*^9}, {3.585480503981059*^9, 3.5854805308222647`*^9}, {
   3.585480828383356*^9, 3.585480844897043*^9}, 3.585481011899619*^9, {
   3.585481261582512*^9, 3.585481292022044*^9}, 3.5854814295871897`*^9, {
   3.585483861915666*^9, 3.5854838691263123`*^9}, {3.585484991600119*^9, 
   3.5854849947913113`*^9}, {3.585485069364324*^9, 3.585485080941546*^9}, 
   3.585485127057515*^9, 3.5854852045462627`*^9, 3.5854854263313293`*^9, 
   3.58549547930477*^9, 3.585495513160664*^9, 3.585495632889965*^9, {
   3.58550100274291*^9, 3.585501024325069*^9}, 3.585501080793311*^9, 
   3.58550163087674*^9, 3.5855023512767973`*^9, {3.585657173065467*^9, 
   3.5856571921535873`*^9}, 3.5856572470992403`*^9, 3.585657371909479*^9, 
   3.585657569186314*^9, 3.585657746198563*^9, {3.585657826232843*^9, 
   3.585657883929962*^9}, 3.5856579146957817`*^9, 3.587798775334564*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CapitalPhi]1Dag", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Phi]", "[", "0", "]"}], "-", 
       RowBox[{"I", " ", 
        RowBox[{"\[Phi]", "[", "1", "]"}]}]}], ")"}], "/", 
     RowBox[{"Sqrt", "[", "2", "]"}]}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Phi]", "[", "2", "]"}], "-", 
       RowBox[{"I", " ", 
        RowBox[{"\[Phi]", "[", "3", "]"}]}]}], ")"}], "/", 
     RowBox[{"Sqrt", "[", "2", "]"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.535109199729326*^9, 3.535109200029863*^9}, {
  3.53510953462142*^9, 3.535109535164555*^9}, {3.535110074312305*^9, 
  3.535110079458116*^9}, {3.535111706207088*^9, 3.535111706549427*^9}, {
  3.535115410604756*^9, 3.535115410974568*^9}, {3.549553589272149*^9, 
  3.549553589294136*^9}, {3.5495536303617373`*^9, 3.5495536304272413`*^9}, {
  3.5496187412780724`*^9, 3.549618763241658*^9}, {3.565089712866297*^9, 
  3.565089721854927*^9}, {3.565092663498235*^9, 3.565092664409509*^9}, {
  3.566636917275683*^9, 3.566636918645827*^9}, {3.566637118684303*^9, 
  3.566637127880097*^9}, {3.566637290440206*^9, 3.566637293504091*^9}, {
  3.570780263370391*^9, 3.570780271608928*^9}, {3.583126435541141*^9, 
  3.583126441786715*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"\[Phi]", "[", "0", "]"}], "-", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"\[Phi]", "[", "1", "]"}]}]}], 
    SqrtBox["2"]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"\[Phi]", "[", "2", "]"}], "-", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"\[Phi]", "[", "3", "]"}]}]}], 
    SqrtBox["2"]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.535109536136553*^9, 3.53511297970275*^9, 3.535115165947134*^9, {
   3.535115404347159*^9, 3.535115411975111*^9}, 3.535278059564253*^9, 
   3.535784418607324*^9, 3.535805282405831*^9, 3.535806163597977*^9, {
   3.536384721430085*^9, 3.536384767407791*^9}, 3.537020508222603*^9, 
   3.5370205964999437`*^9, 3.537189598911167*^9, 3.547361880431159*^9, 
   3.5473653958339252`*^9, 3.547365821748208*^9, 3.547905703027606*^9, 
   3.5484829144440928`*^9, {3.54955362680056*^9, 3.5495536318513927`*^9}, 
   3.5495540396642313`*^9, 3.549555530541011*^9, 3.549555848016901*^9, {
   3.549555997320868*^9, 3.5495560236449003`*^9}, 3.5495669493263206`*^9, 
   3.549600643604191*^9, 3.5496006911698027`*^9, {3.5496187228588057`*^9, 
   3.5496187485891*^9}, 3.5496194167279177`*^9, 3.549620983841875*^9, 
   3.5496210632086153`*^9, {3.54962115410704*^9, 3.549621179388376*^9}, 
   3.54962165502177*^9, 3.549621706293095*^9, 3.5497068453436832`*^9, 
   3.549711878065778*^9, 3.552302631944517*^9, 3.5523027325171328`*^9, 
   3.552302812672686*^9, 3.5523055028230762`*^9, 3.552842049456295*^9, 
   3.555738441132964*^9, 3.555741444525577*^9, 3.570347593438706*^9, 
   3.570780278138885*^9, 3.570782347948301*^9, 3.570801957254089*^9, 
   3.570802000921617*^9, 3.570802122868432*^9, 3.570802161418197*^9, 
   3.570802221419132*^9, 3.570802303156346*^9, 3.573370250693198*^9, {
   3.577100674596106*^9, 3.5771006831698847`*^9}, 3.5771009117233*^9, 
   3.577102192738039*^9, 3.583126840330243*^9, 3.5831271778269787`*^9, 
   3.583140376533866*^9, 3.583140446138136*^9, 3.5831405177246304`*^9, 
   3.583141544741438*^9, 3.5831419045702753`*^9, 3.583143620749711*^9, 
   3.583143650770864*^9, 3.583758931885228*^9, 3.583764307427608*^9, 
   3.583764500192922*^9, 3.583765327791109*^9, {3.5854800403485622`*^9, 
   3.585480057382058*^9}, {3.585480149161914*^9, 3.585480158929309*^9}, {
   3.5854802003032093`*^9, 3.5854802088020144`*^9}, {3.585480504083839*^9, 
   3.5854805310292397`*^9}, {3.585480828413793*^9, 3.58548084492684*^9}, 
   3.5854810119248743`*^9, {3.5854812616869593`*^9, 3.585481292119055*^9}, 
   3.585481429615769*^9, {3.5854838619710693`*^9, 3.585483869149685*^9}, {
   3.585484991629231*^9, 3.585484994897126*^9}, {3.585485069519537*^9, 
   3.585485081124069*^9}, 3.5854851270822372`*^9, 3.585485204723464*^9, 
   3.585485426449129*^9, 3.58549547933384*^9, 3.585495513192103*^9, 
   3.58549563291991*^9, {3.5855010027686033`*^9, 3.585501024369157*^9}, 
   3.585501080824758*^9, 3.585501631051302*^9, 3.58550235139354*^9, {
   3.5856571730924187`*^9, 3.5856571923086348`*^9}, 3.585657247226851*^9, 
   3.58565737213406*^9, 3.5856575693203506`*^9, 3.5856577462240763`*^9, {
   3.585657826414122*^9, 3.585657884076195*^9}, 3.5856579148270683`*^9, 
   3.587798775352339*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CapitalPhi]2", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Phi]", "[", "4", "]"}], "+", 
       RowBox[{"I", " ", 
        RowBox[{"\[Phi]", "[", "5", "]"}]}]}], ")"}], "/", 
     RowBox[{"Sqrt", "[", "2", "]"}]}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Phi]", "[", "6", "]"}], "+", 
       RowBox[{"I", " ", 
        RowBox[{"\[Phi]", "[", "7", "]"}]}]}], ")"}], "/", 
     RowBox[{"Sqrt", "[", "2", "]"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.549618764769656*^9, 3.5496187702269573`*^9}, {
  3.563002584479318*^9, 3.563002599228941*^9}, {3.566637273703445*^9, 
  3.566637282579597*^9}, {3.570779429412612*^9, 3.57077945600967*^9}, {
  3.570780291194472*^9, 3.570780308812855*^9}, {3.583126444200058*^9, 
  3.583126449305698*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"\[Phi]", "[", "4", "]"}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"\[Phi]", "[", "5", "]"}]}]}], 
    SqrtBox["2"]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"\[Phi]", "[", "6", "]"}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"\[Phi]", "[", "7", "]"}]}]}], 
    SqrtBox["2"]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.570780346601282*^9, 3.570782348054008*^9, 3.570801957347242*^9, 
   3.570802000985834*^9, 3.570802123118985*^9, 3.570802161506234*^9, 
   3.570802221488554*^9, 3.570802303318881*^9, 3.573370250771912*^9, {
   3.5771006746229258`*^9, 3.5771006832599087`*^9}, 3.577100911978389*^9, 
   3.577102192753706*^9, 3.5831268405206614`*^9, 3.5831271779989567`*^9, 
   3.583140376823208*^9, 3.583140446430168*^9, 3.583140517886548*^9, 
   3.583141545039342*^9, 3.583141904874168*^9, 3.583143620770966*^9, 
   3.583143650793816*^9, 3.583758932164872*^9, 3.5837643076903048`*^9, 
   3.5837645004901657`*^9, 3.583765328126136*^9, {3.585480040375993*^9, 
   3.585480057412497*^9}, {3.5854801491900463`*^9, 3.585480158956492*^9}, {
   3.585480200334222*^9, 3.5854802088321733`*^9}, {3.585480504111205*^9, 
   3.585480531060463*^9}, {3.585480828444807*^9, 3.585480844956789*^9}, 
   3.5854810120412188`*^9, {3.585481261714574*^9, 3.585481292149828*^9}, 
   3.5854814297723846`*^9, {3.585483861997044*^9, 3.5854838691717033`*^9}, {
   3.58548499165786*^9, 3.5854849949320173`*^9}, {3.5854850696677523`*^9, 
   3.585485081292769*^9}, 3.585485127239545*^9, 3.585485204874608*^9, 
   3.585485426472546*^9, 3.585495479364066*^9, 3.585495513317865*^9, 
   3.585495632947315*^9, {3.585501002791709*^9, 3.585501024490181*^9}, 
   3.585501080852581*^9, 3.58550163108727*^9, 3.585502351602419*^9, {
   3.5856571731250887`*^9, 3.585657192349846*^9}, 3.585657247263158*^9, 
   3.5856573722397614`*^9, 3.585657569359248*^9, 3.5856577462496233`*^9, {
   3.585657826569096*^9, 3.585657884222698*^9}, 3.5856579148669357`*^9, 
   3.5877987753701487`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CapitalPhi]2Dag", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Phi]", "[", "4", "]"}], "-", 
       RowBox[{"I", " ", 
        RowBox[{"\[Phi]", "[", "5", "]"}]}]}], ")"}], "/", 
     RowBox[{"Sqrt", "[", "2", "]"}]}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Phi]", "[", "6", "]"}], "-", 
       RowBox[{"I", " ", 
        RowBox[{"\[Phi]", "[", "7", "]"}]}]}], ")"}], "/", 
     RowBox[{"Sqrt", "[", "2", "]"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.549618781513886*^9, 3.5496187832577333`*^9}, {
  3.566637285796927*^9, 3.56663730892208*^9}, {3.570780342736515*^9, 
  3.570780352659683*^9}, {3.583126453380465*^9, 3.5831264592357273`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"\[Phi]", "[", "4", "]"}], "-", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"\[Phi]", "[", "5", "]"}]}]}], 
    SqrtBox["2"]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"\[Phi]", "[", "6", "]"}], "-", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"\[Phi]", "[", "7", "]"}]}]}], 
    SqrtBox["2"]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.549618784025077*^9, 3.549619416777308*^9, 3.549620984013175*^9, 
   3.549621063422876*^9, {3.549621154327694*^9, 3.5496211796874437`*^9}, 
   3.5496216550449667`*^9, 3.549621706315928*^9, 3.5497068461074057`*^9, 
   3.549711878211996*^9, 3.552302631999094*^9, 3.552302732540604*^9, 
   3.552302812743764*^9, 3.552305502847011*^9, 3.552842049484744*^9, 
   3.555738441206912*^9, 3.555741444622259*^9, 3.570347593958298*^9, 
   3.570780353408888*^9, 3.570782348288912*^9, 3.570801957439808*^9, 
   3.570802001049767*^9, 3.570802123172003*^9, 3.570802161525991*^9, 
   3.570802221504252*^9, 3.570802303441547*^9, 3.573370250872563*^9, {
   3.577100674651019*^9, 3.577100683359651*^9}, 3.577100912221837*^9, 
   3.577102192768567*^9, 3.5831268407790318`*^9, 3.583127178028216*^9, 
   3.5831403771192923`*^9, 3.58314044657303*^9, 3.583140518169594*^9, 
   3.583141545332766*^9, 3.583141905022249*^9, 3.583143620877715*^9, 
   3.5831436509137983`*^9, 3.583758932470837*^9, 3.5837643080253572`*^9, 
   3.583764500845117*^9, 3.583765328400403*^9, {3.5854800404014177`*^9, 
   3.585480057442377*^9}, {3.585480149218944*^9, 3.585480158979529*^9}, {
   3.5854802003602457`*^9, 3.585480208863248*^9}, {3.585480504135206*^9, 
   3.5854805310882893`*^9}, {3.5854808284757147`*^9, 3.585480845088469*^9}, 
   3.585481012068084*^9, {3.585481261737444*^9, 3.585481292180888*^9}, 
   3.585481429805312*^9, {3.5854838620764847`*^9, 3.585483869192624*^9}, {
   3.5854849916864557`*^9, 3.5854849949657583`*^9}, {3.58548506970336*^9, 
   3.585485081470427*^9}, 3.58548512740105*^9, 3.585485205039547*^9, 
   3.585485426498279*^9, 3.5854954793910427`*^9, 3.58549551334934*^9, 
   3.585495633050075*^9, {3.585501002815011*^9, 3.585501024520792*^9}, 
   3.5855010809696617`*^9, 3.585501631115972*^9, 3.585502351747164*^9, {
   3.585657173150609*^9, 3.585657192381917*^9}, 3.585657247294751*^9, 
   3.585657372458053*^9, 3.585657569390242*^9, 3.585657746279716*^9, {
   3.585657826593946*^9, 3.585657884265794*^9}, 3.585657914905835*^9, 
   3.587798775386977*^9}]
}, Open  ]],

Cell["\<\
The Vscalar quantity always has to be defined. This is the scalar potential \
that will be passed to the cpp code through the input file generated by this \
notebook\
\>", "Text",
 CellChangeTimes->{{3.58547972633412*^9, 3.5854797380006313`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Vscalar", "=", 
  RowBox[{"ComplexExpand", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Lambda]", "[", "0", "]"}], 
     RowBox[{"\[CapitalPhi]1Dag", ".", "\[CapitalPhi]1"}]}], "+", 
    RowBox[{
     RowBox[{"\[Lambda]", "[", "1", "]"}], " ", 
     RowBox[{"\[CapitalPhi]2Dag", ".", "\[CapitalPhi]2"}]}], "-", 
    RowBox[{
     RowBox[{"\[Lambda]", "[", "2", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[CapitalPhi]1Dag", ".", "\[CapitalPhi]2"}], "+", 
       RowBox[{"\[CapitalPhi]2Dag", ".", "\[CapitalPhi]1"}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Lambda]", "[", "3", "]"}], "/", "2"}], " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"\[CapitalPhi]1Dag", ".", "\[CapitalPhi]1"}], ")"}], "^", 
      "2"}]}], " ", "+", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Lambda]", "[", "4", "]"}], " ", "/", "2"}], " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"\[CapitalPhi]2Dag", ".", "\[CapitalPhi]2"}], ")"}], "^", 
      "2"}]}], "+", 
    RowBox[{
     RowBox[{"\[Lambda]", "[", "5", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{"\[CapitalPhi]1Dag", ".", "\[CapitalPhi]1"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"\[CapitalPhi]2Dag", ".", "\[CapitalPhi]2"}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"\[Lambda]", "[", "6", "]"}], 
     RowBox[{"(", 
      RowBox[{"\[CapitalPhi]2Dag", ".", "\[CapitalPhi]1"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"\[CapitalPhi]1Dag", ".", "\[CapitalPhi]2"}], ")"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Lambda]", "[", "7", "]"}], "/", "2"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[CapitalPhi]1Dag", ".", "\[CapitalPhi]2"}], ")"}], "^", 
        "2"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[CapitalPhi]2Dag", ".", "\[CapitalPhi]1"}], ")"}], "^", 
        "2"}]}], ")"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.534144310207885*^9, 3.5341444506966047`*^9}, {
   3.534144490509598*^9, 3.53414458883617*^9}, {3.534144624519189*^9, 
   3.534144666441533*^9}, {3.534178088516856*^9, 3.534178111806834*^9}, {
   3.534178147673089*^9, 3.5341781921278267`*^9}, {3.534178224906232*^9, 
   3.534178242164892*^9}, {3.5342465770748453`*^9, 3.5342465879329967`*^9}, {
   3.53424662105466*^9, 3.5342466564110603`*^9}, {3.53510999916111*^9, 
   3.535110001047953*^9}, {3.53511005129663*^9, 3.535110051792281*^9}, {
   3.535110277667881*^9, 3.535110290667621*^9}, {3.535110760050255*^9, 
   3.535110761128691*^9}, 3.535111722829476*^9, {3.535112079559593*^9, 
   3.535112145279432*^9}, {3.535112452325189*^9, 3.535112534267795*^9}, {
   3.535112896297239*^9, 3.535112912268751*^9}, {3.535115195852663*^9, 
   3.535115308267053*^9}, {3.535784382495168*^9, 3.535784383535134*^9}, {
   3.535805240382502*^9, 3.535805241186414*^9}, {3.536384713321053*^9, 
   3.5363847140485077`*^9}, {3.537020326846611*^9, 3.53702034303214*^9}, {
   3.537020416238227*^9, 3.5370204701153297`*^9}, 3.537189581054373*^9, 
   3.538305507421482*^9, {3.547906780982019*^9, 3.547906795151812*^9}, {
   3.5484835535811167`*^9, 3.548483554435574*^9}, {3.5495536372529383`*^9, 
   3.54955368415438*^9}, {3.5495558345272703`*^9, 3.5495558345724993`*^9}, 
   3.549555984248444*^9, 3.549556019979096*^9, {3.549618831668489*^9, 
   3.549618903965797*^9}, {3.549620947291133*^9, 3.549620954260638*^9}, {
   3.549706769625893*^9, 3.549706774600843*^9}, {3.563002618635407*^9, 
   3.563002639581672*^9}, {3.563003917132162*^9, 3.563003968937449*^9}, {
   3.563005825040492*^9, 3.563005866097913*^9}, {3.566637402030693*^9, 
   3.566637402660519*^9}, {3.566637469465615*^9, 3.566637476736376*^9}, {
   3.566637516045632*^9, 3.566637602565646*^9}, {3.566637637466981*^9, 
   3.5666376384839*^9}, {3.56663768016229*^9, 3.566637696295292*^9}, {
   3.566637741054867*^9, 3.566637768054602*^9}, {3.566637829628353*^9, 
   3.566637855787619*^9}, {3.566644882033549*^9, 3.566644902937996*^9}, {
   3.566644998329653*^9, 3.566645000939214*^9}, 3.566646094522893*^9, 
   3.566646139462853*^9, 3.566646182418709*^9, 3.566646279403314*^9, {
   3.566646322090582*^9, 3.566646362101699*^9}, {3.583126462629496*^9, 
   3.5831264846759377`*^9}, {3.5854794846064167`*^9, 3.585479520218713*^9}, 
   3.585479720778413*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"\[Lambda]", "[", "0", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "0", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   RowBox[{"\[Lambda]", "[", "3", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "0", "]"}], "4"]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"\[Lambda]", "[", "0", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "1", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "3", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "0", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "1", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   RowBox[{"\[Lambda]", "[", "3", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "1", "]"}], "4"]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"\[Lambda]", "[", "0", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "2", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "3", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "0", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "2", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "3", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "1", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "2", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   RowBox[{"\[Lambda]", "[", "3", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "2", "]"}], "4"]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"\[Lambda]", "[", "0", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "3", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "3", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "0", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "3", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "3", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "1", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "3", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "3", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "2", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "3", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   RowBox[{"\[Lambda]", "[", "3", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "3", "]"}], "4"]}], "-", 
  RowBox[{
   RowBox[{"\[Lambda]", "[", "2", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "0", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "4", "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"\[Lambda]", "[", "1", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "4", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "5", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "0", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "4", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "6", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "0", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "4", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "7", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "0", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "4", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "5", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "1", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "4", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "6", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "1", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "4", "]"}], "2"]}], "-", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "7", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "1", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "4", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "5", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "2", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "4", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "5", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "3", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "4", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   RowBox[{"\[Lambda]", "[", "4", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "4", "]"}], "4"]}], "-", 
  RowBox[{
   RowBox[{"\[Lambda]", "[", "2", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "1", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "5", "]"}]}], "+", 
  RowBox[{
   RowBox[{"\[Lambda]", "[", "7", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "0", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "1", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "4", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "5", "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"\[Lambda]", "[", "1", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "5", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "5", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "0", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "5", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "6", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "0", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "5", "]"}], "2"]}], "-", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "7", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "0", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "5", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "5", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "1", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "5", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "6", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "1", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "5", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "7", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "1", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "5", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "5", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "2", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "5", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "5", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "3", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "5", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "4", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "4", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "5", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   RowBox[{"\[Lambda]", "[", "4", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "5", "]"}], "4"]}], "-", 
  RowBox[{
   RowBox[{"\[Lambda]", "[", "2", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "2", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "6", "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"\[Lambda]", "[", "6", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "0", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "2", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "4", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "6", "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"\[Lambda]", "[", "7", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "0", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "2", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "4", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "6", "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"\[Lambda]", "[", "6", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "1", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "3", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "4", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "6", "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"\[Lambda]", "[", "7", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "1", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "3", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "4", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "6", "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"\[Lambda]", "[", "6", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "1", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "2", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "5", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "6", "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"\[Lambda]", "[", "7", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "1", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "2", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "5", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "6", "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"\[Lambda]", "[", "6", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "0", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "3", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "5", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "6", "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"\[Lambda]", "[", "7", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "0", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "3", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "5", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "6", "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"\[Lambda]", "[", "1", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "6", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "5", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "0", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "6", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "5", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "1", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "6", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "5", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "2", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "6", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "6", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "2", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "6", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "7", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "2", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "6", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "5", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "3", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "6", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "6", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "3", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "6", "]"}], "2"]}], "-", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "7", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "3", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "6", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "4", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "4", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "6", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "4", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "5", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "6", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   RowBox[{"\[Lambda]", "[", "4", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "6", "]"}], "4"]}], "-", 
  RowBox[{
   RowBox[{"\[Lambda]", "[", "2", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "3", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "7", "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"\[Lambda]", "[", "6", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "1", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "2", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "4", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "7", "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"\[Lambda]", "[", "7", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "1", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "2", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "4", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "7", "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"\[Lambda]", "[", "6", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "0", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "3", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "4", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "7", "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"\[Lambda]", "[", "7", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "0", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "3", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "4", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "7", "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"\[Lambda]", "[", "6", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "0", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "2", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "5", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "7", "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"\[Lambda]", "[", "7", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "0", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "2", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "5", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "7", "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"\[Lambda]", "[", "6", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "1", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "3", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "5", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "7", "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"\[Lambda]", "[", "7", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "1", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "3", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "5", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "7", "]"}]}], "+", 
  RowBox[{
   RowBox[{"\[Lambda]", "[", "7", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "2", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "3", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "6", "]"}], " ", 
   RowBox[{"\[Phi]", "[", "7", "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"\[Lambda]", "[", "1", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "7", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "5", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "0", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "7", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "5", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "1", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "7", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "5", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "2", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "7", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "6", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "2", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "7", "]"}], "2"]}], "-", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "7", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "2", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "7", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "5", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "3", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "7", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "6", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "3", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "7", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "7", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "3", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "7", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "4", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "4", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "7", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "4", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "5", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "7", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"\[Lambda]", "[", "4", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "6", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "7", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   RowBox[{"\[Lambda]", "[", "4", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Phi]", "[", "7", "]"}], "4"]}]}]], "Output",
 CellChangeTimes->{
  3.549553688644093*^9, 3.549554039687963*^9, 3.549555530601707*^9, 
   3.549555848034932*^9, {3.5495559974421377`*^9, 3.549556023744195*^9}, 
   3.549566949367874*^9, 3.5496006436360598`*^9, 3.5496006912214403`*^9, 
   3.549618907268854*^9, 3.5496194168355007`*^9, 3.5496209841571417`*^9, 
   3.549621063497464*^9, {3.5496211544701147`*^9, 3.54962117981526*^9}, 
   3.5496216551061783`*^9, 3.549621706388008*^9, 3.549706846546579*^9, 
   3.5497118783307123`*^9, 3.5523026321262503`*^9, 3.552302732594841*^9, 
   3.552302812801145*^9, 3.552305502904253*^9, 3.552842049532589*^9, 
   3.555738441253096*^9, 3.55574144469486*^9, 3.570347594470019*^9, 
   3.570780359979332*^9, 3.570782348939485*^9, 3.5708019576759*^9, 
   3.570802001141002*^9, 3.570802123576994*^9, 3.570802161608792*^9, 
   3.57080222159209*^9, 3.570802303763793*^9, 3.573370251055904*^9, {
   3.5771006749764*^9, 3.5771006834427433`*^9}, 3.577100912709074*^9, 
   3.577102193120843*^9, 3.5831268411420383`*^9, 3.583127178175931*^9, 
   3.5831403775850286`*^9, 3.5831404468537607`*^9, 3.583140518458955*^9, 
   3.5831415456490717`*^9, 3.5831419057214527`*^9, 3.58314362101892*^9, 
   3.5831436510472527`*^9, 3.5837589331147003`*^9, 3.58376430871397*^9, 
   3.5837645014029837`*^9, 3.583765328929957*^9, {3.5854800406797523`*^9, 
   3.5854800576124687`*^9}, {3.585480149402946*^9, 3.5854801591232157`*^9}, {
   3.58548020054023*^9, 3.585480209040914*^9}, {3.5854805043043747`*^9, 
   3.585480531237626*^9}, {3.58548082863558*^9, 3.585480845374082*^9}, 
   3.585481012265594*^9, {3.58548126186736*^9, 3.585481292315051*^9}, 
   3.58548143004659*^9, {3.585483862181725*^9, 3.5854838692892437`*^9}, {
   3.5854849918280497`*^9, 3.5854849950971317`*^9}, {3.5854850698564577`*^9, 
   3.585485081664442*^9}, 3.58548512759569*^9, 3.585485205223382*^9, 
   3.5854854266513147`*^9, 3.5854954795318117`*^9, 3.585495513493376*^9, 
   3.585495633175219*^9, {3.5855010029632263`*^9, 3.5855010246547947`*^9}, 
   3.5855010811014223`*^9, 3.585501631396014*^9, 3.5855023519424877`*^9, {
   3.5856571733180323`*^9, 3.585657192647743*^9}, 3.585657247514949*^9, 
   3.585657372941388*^9, 3.585657569673048*^9, 3.585657746516334*^9, {
   3.5856578267411547`*^9, 3.585657884539351*^9}, 3.585657915281763*^9, 
   3.587798775557272*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["VEV Ranges (in case a simple hypercubic box is chosen)", "Subsection",
 CellChangeTimes->{{3.546865685914077*^9, 3.5468656870094137`*^9}, {
  3.585482911811902*^9, 3.5854829161180058`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Initializing", " ", "all", " ", "ranges", " ", "to", " ", "zero"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i", "=", "0"}], ",", 
    RowBox[{"i", "<", "Nreal"}], ",", 
    RowBox[{"++", "i"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Phi]Min", "[", "i", "]"}], "=", "0"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\[Phi]Max", "[", "i", "]"}], "=", "0"}], ";"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.583126509647599*^9, 3.583126516495706*^9}, {
  3.585482829270853*^9, 3.5854828627618647`*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Now", " ", "defining", " ", "the", " ", "non"}], "-", 
   RowBox[{"zero", " ", "ranges"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.585482848181301*^9, 3.585482860081266*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[Phi]Min", "[", "2", "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Phi]Max", "[", "2", "]"}], "=", "246"}], ";"}]}], "Input",
 CellChangeTimes->{{3.549640440750679*^9, 3.54964044199866*^9}, {
   3.549640552214943*^9, 3.5496405532412663`*^9}, {3.5830840323108587`*^9, 
   3.583084033277264*^9}, {3.583084079528722*^9, 3.5830840809419813`*^9}, 
   3.5831265684527063`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[Phi]Min", "[", "6", "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Phi]Max", "[", "6", "]"}], "=", "246"}], ";"}]}], "Input",
 CellChangeTimes->{{3.5497086039551287`*^9, 3.549708605027857*^9}, {
   3.552574817509997*^9, 3.552574817921376*^9}, {3.555740313591342*^9, 
   3.5557403138962927`*^9}, 3.5830741737471848`*^9, {3.583084043748694*^9, 
   3.58308404510778*^9}, {3.583084088600975*^9, 3.583084090382546*^9}, {
   3.583126563573991*^9, 3.583126571281637*^9}}],

Cell[CellGroupData[{

Cell["\<\
Parametrized VEV ranges (optional --  ON if  NparamsVEVs > 0)\
\>", "Subsubsection",
 CellChangeTimes->{{3.5854829702489777`*^9, 3.585483004325163*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Initializing", " ", "all", " ", "ranges", " ", "to", " ", "zero"}],
   " ", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"For", "[", 
  RowBox[{
   RowBox[{"i", "=", "0"}], ",", 
   RowBox[{"i", "<", "NparamsVEVs"}], ",", 
   RowBox[{"++", "i"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]ParMin", "[", "i", "]"}], "=", "0"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[Phi]ParMax", "[", "i", "]"}], "=", "0"}], ";"}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.583126581349114*^9, 3.5831266062864437`*^9}, 
   3.585478893972082*^9}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
   "Then", " ", "initialize", " ", "ranges", " ", "for", " ", "parameters", 
    " ", "used", " ", "in", " ", "the", " ", "parametrization", " ", 
    "defined", " ", "in", " ", "the", " ", "user"}], "-", 
   RowBox[{
   "defined", " ", "function", " ", "\"\<MyPhiParametrization\>\"", " ", "in",
     " ", 
    RowBox[{"ScannerSUser", ".", "cpp"}]}]}], " ", " ", "*)"}]], "Input",
 CellChangeTimes->{{3.5854830348626966`*^9, 3.585483081032977*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[Phi]ParMin", "[", "0", "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Phi]ParMax", "[", "0", "]"}], "=", 
   RowBox[{"2.", "*", "Pi"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.549640419086753*^9, 3.549640426375087*^9}, {
  3.549640544747589*^9, 3.549640545463179*^9}, {3.5830718657475977`*^9, 
  3.583071880718238*^9}, {3.583071916677647*^9, 3.583071918359364*^9}, {
  3.583071955764485*^9, 3.5830719559831743`*^9}, {3.583072728597533*^9, 
  3.583072743941885*^9}, {3.58308406561486*^9, 3.5830840673143587`*^9}, {
  3.5831198193998013`*^9, 3.583119833680192*^9}, {3.583126620567246*^9, 
  3.5831266357285147`*^9}, {3.583758520617651*^9, 3.583758522844577*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Parametrized Mixing matrix ranges (optional --  ON if  NparamsMixing> 0)\
\>", "Subsubsection",
 CellChangeTimes->{{3.5854829702489777`*^9, 3.585483004325163*^9}, {
  3.585500564066173*^9, 3.585500571760414*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Initializing", " ", "all", " ", "ranges", " ", "to", " ", "zero"}],
   " ", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"For", "[", 
  RowBox[{
   RowBox[{"i", "=", "0"}], ",", 
   RowBox[{"i", "<", "NparamsMixing"}], ",", 
   RowBox[{"++", "i"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"MixParMin", "[", "i", "]"}], "=", "0"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"MixParMax", "[", "i", "]"}], "=", "0"}], ";"}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.583126581349114*^9, 3.5831266062864437`*^9}, 
   3.585478893972082*^9, {3.585500575180869*^9, 3.585500581835403*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
   "Then", " ", "initialize", " ", "ranges", " ", "for", " ", "parameters", 
    " ", "used", " ", "in", " ", "the", " ", "parametrization", " ", 
    "defined", " ", "in", " ", "the", " ", "user"}], "-", 
   RowBox[{
   "defined", " ", "function", " ", "\"\<MyPhiParametrization\>\"", " ", "in",
     " ", 
    RowBox[{"ScannerSUser", ".", "cpp"}]}]}], " ", " ", "*)"}]], "Input",
 CellChangeTimes->{{3.5854830348626966`*^9, 3.585483081032977*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"MixParMin", "[", "0", "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MixParMax", "[", "0", "]"}], "=", 
   RowBox[{"2.", "*", "Pi", "*", "0"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.549640419086753*^9, 3.549640426375087*^9}, {
  3.549640544747589*^9, 3.549640545463179*^9}, {3.5830718657475977`*^9, 
  3.583071880718238*^9}, {3.583071916677647*^9, 3.583071918359364*^9}, {
  3.583071955764485*^9, 3.5830719559831743`*^9}, {3.583072728597533*^9, 
  3.583072743941885*^9}, {3.58308406561486*^9, 3.5830840673143587`*^9}, {
  3.5831198193998013`*^9, 3.583119833680192*^9}, {3.583126620567246*^9, 
  3.5831266357285147`*^9}, {3.583758520617651*^9, 3.583758522844577*^9}, {
  3.58550058811054*^9, 3.5855005912346077`*^9}, {3.5855016275648623`*^9, 
  3.585501627770669*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Couplings and masses Ranges (always checked)", "Subsection",
 CellChangeTimes->{{3.585483121735176*^9, 3.585483194741048*^9}}],

Cell[CellGroupData[{

Cell["Coupling ranges", "Subsubsection",
 CellChangeTimes->{{3.585483247691101*^9, 3.585483250834515*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"m11", "^", "2"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Lambda]Min", "[", "0", "]"}], "=", 
     RowBox[{"-", 
      RowBox[{"10", "^", "6"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Lambda]Max", "[", "0", "]"}], "=", 
     RowBox[{"10", "^", "6"}]}], ";"}], "\n", 
   RowBox[{"(*", " ", 
    RowBox[{"m22", "^", "2"}], "*)"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Lambda]Min", "[", "1", "]"}], "=", 
     RowBox[{"-", 
      RowBox[{"10", "^", "6"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Lambda]Max", "[", "1", "]"}], "=", 
     RowBox[{"10", "^", "6"}]}], ";"}], "\n", 
   RowBox[{"(*", " ", 
    RowBox[{"m12", "^", "2"}], "*)"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Lambda]Min", "[", "2", "]"}], "=", 
     RowBox[{"-", 
      RowBox[{"10", "^", "6"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Lambda]Max", "[", "2", "]"}], "=", 
     RowBox[{"10", "^", "6"}]}], ";"}], "\n", "  ", 
   RowBox[{"(*", " ", "lambda1", " ", "*)"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Lambda]Min", "[", "3", "]"}], "=", 
     RowBox[{"-", "10"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Lambda]Max", "[", "3", "]"}], "=", " ", "10"}], ";"}], "\n", 
   "  ", 
   RowBox[{"(*", " ", "lambda2", " ", "*)"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Lambda]Min", "[", "4", "]"}], "=", 
     RowBox[{"-", "10"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Lambda]Max", "[", "4", "]"}], "=", "10"}], ";"}], "\n", "  ", 
   
   RowBox[{"(*", " ", "lambda3", " ", "*)"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Lambda]Min", "[", "5", "]"}], "=", 
     RowBox[{"-", "10"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Lambda]Max", "[", "5", "]"}], "=", " ", "10"}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.546865971934822*^9, 3.546866141749364*^9}, {
  3.54736590838002*^9, 3.547365950861902*^9}, {3.5495537902842817`*^9, 
  3.54955382098479*^9}, {3.549553853679388*^9, 3.549553982174777*^9}, {
  3.549566937249063*^9, 3.5495669446538687`*^9}, {3.549618978213484*^9, 
  3.549619137635911*^9}, {3.549619179935617*^9, 3.549619290523549*^9}, {
  3.5496209612335463`*^9, 3.549620961646048*^9}, {3.54970676170907*^9, 
  3.5497067633455143`*^9}, {3.552302726898242*^9, 3.552302728204114*^9}, {
  3.552302799556973*^9, 3.552302802056004*^9}, {3.555736872697688*^9, 
  3.555736887503777*^9}, {3.555738408882618*^9, 3.5557384285287857`*^9}, {
  3.555741414612959*^9, 3.5557414335266848`*^9}, {3.568360679305075*^9, 
  3.568360740060766*^9}, {3.570801886222523*^9, 3.570801926361846*^9}, {
  3.583126685576461*^9, 3.5831267223333273`*^9}, {3.585483228767868*^9, 
  3.585483229855309*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "  ", 
  RowBox[{"(*", " ", "lambda4", " ", "*)"}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Lambda]Min", "[", "6", "]"}], "=", 
     RowBox[{"-", "10"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Lambda]Max", "[", "6", "]"}], "=", " ", "10"}], ";"}], "\n", 
   "  ", 
   RowBox[{"(*", " ", "lambda5", " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Lambda]Min", "[", "7", "]"}], "=", 
     RowBox[{"-", "10"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Lambda]Max", "[", "7", "]"}], "=", " ", "10"}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.568360748277626*^9, 3.568360772398319*^9}, {
  3.570801933871536*^9, 3.570801940909851*^9}, {3.5831267246278677`*^9, 
  3.583126737494256*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mass ranges", "Subsubsection",
 CellChangeTimes->{{3.58548326035649*^9, 3.585483262384583*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Initialise", " ", "a", " ", "common", " ", "box", " ", "for", " ", 
    "example"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i", "=", "0"}], ",", 
    RowBox[{"i", "<", "Nreal"}], ",", 
    RowBox[{"++", "i"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"massmin", "[", "i", "]"}], "=", "0"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"massmax", "[", "i", "]"}], "=", "400"}], ";"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.547361770015276*^9, 3.547361784801909*^9}, {
  3.549600627318317*^9, 3.549600629953188*^9}, {3.549600685742124*^9, 
  3.549600685923493*^9}, {3.549619309369874*^9, 3.5496193161470957`*^9}, {
  3.552302626409864*^9, 3.5523026264460297`*^9}, {3.552305498544632*^9, 
  3.5523054986004677`*^9}, {3.55573843254038*^9, 3.55573843280478*^9}, {
  3.5557414381981497`*^9, 3.5557414384977827`*^9}, {3.577100843939396*^9, 
  3.5771008476465683`*^9}, {3.5831267742240143`*^9, 3.583126776985683*^9}, {
  3.583143617104957*^9, 3.5831436176123867`*^9}, {3.585483287588677*^9, 
  3.585483297690172*^9}, {3.585483366571311*^9, 3.58548337243007*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Specific", " ", "mass", " ", "for", " ", "a", " ", "certain", " ", 
   "particle"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.585483301893355*^9, 3.585483313515202*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"massmin", "[", "0", "]"}], "=", "125"}], ";"}]], "Input",
 CellChangeTimes->{{3.549619343086762*^9, 3.5496193554912987`*^9}, {
   3.549621392217161*^9, 3.549621392246396*^9}, {3.57078233320813*^9, 
   3.570782333509603*^9}, {3.577100612135137*^9, 3.5771006133111057`*^9}, 
   3.583126822205221*^9, {3.587798764476585*^9, 3.587798765427034*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"massmax", "[", "0", "]"}], "=", "125"}], ";"}]], "Input",
 CellChangeTimes->{{3.549619356594325*^9, 3.5496193624912987`*^9}, {
   3.5496213953506613`*^9, 3.549621395402425*^9}, {3.57078233633569*^9, 
   3.570782336658552*^9}, {3.57710061746104*^9, 3.57710061824796*^9}, 
   3.583126823565724*^9, {3.5877987687556677`*^9, 3.587798769530575*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Parametrized Mass/Coupling relations (optional --  ON if  NparamsMassL > 0)\
\>", "Subsubsection",
 CellChangeTimes->{{3.5854833856917877`*^9, 3.585483428222928*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Initializing", " ", "all", " ", "ranges", " ", "to", " ", "zero"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i", "=", "0"}], ",", 
    RowBox[{"i", "<", "NparamsMassL"}], " ", ",", 
    RowBox[{"++", "i"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"MLParMin", "[", "i", "]"}], "=", "0"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"MLParMax", "[", "i", "]"}], "=", "0"}], ";"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.583126581349114*^9, 3.5831266062864437`*^9}, {
  3.5837585897426977`*^9, 3.5837586000189342`*^9}, {3.585483442537485*^9, 
  3.585483443350686*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Set", " ", "range", " ", "for", " ", "a", " ", "specific", " ", 
   "parameter"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.585483453144602*^9, 3.5854834838163023`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"MLParMin", "[", "0", "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MLParMax", "[", "0", "]"}], "=", "400"}], ";"}]}], "Input",
 CellChangeTimes->{{3.549640419086753*^9, 3.549640426375087*^9}, {
  3.549640544747589*^9, 3.549640545463179*^9}, {3.5830718657475977`*^9, 
  3.583071880718238*^9}, {3.583071916677647*^9, 3.583071918359364*^9}, {
  3.583071955764485*^9, 3.5830719559831743`*^9}, {3.583072728597533*^9, 
  3.583072743941885*^9}, {3.58308406561486*^9, 3.5830840673143587`*^9}, {
  3.5831198193998013`*^9, 3.583119833680192*^9}, {3.583126620567246*^9, 
  3.5831266357285147`*^9}, {3.583758520617651*^9, 3.583758522844577*^9}, {
  3.5837586019895277`*^9, 3.583758604048403*^9}, {3.583758753965784*^9, 
  3.5837587626114902`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Path and name of the file where to write", "Subsection",
 CellChangeTimes->{{3.534140116963636*^9, 3.534140127398847*^9}, {
  3.534140263482255*^9, 3.534140264947093*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"InputFileName", "=", "\"\<model.in\>\""}], ";"}]], "Input",
 CellChangeTimes->{{3.58548137552264*^9, 3.585481390727833*^9}, {
  3.585657014150157*^9, 3.585657014295321*^9}, {3.585657801196809*^9, 
  3.585657801516176*^9}, {3.585657904770303*^9, 3.5856579048798237`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "PathToScannerSDir", "=", 
   "\"\</home/mops2/Work/Computational/ProgramsCodes/scanners/trunk/code/\
Current/\>\""}], ";"}]], "Input",
 CellChangeTimes->{{3.5856570094083242`*^9, 3.585657042113365*^9}, {
  3.585657212418953*^9, 3.585657213695766*^9}, {3.585657463462956*^9, 
  3.585657464655715*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Final call to generate input file (do not change this section!)\
\>", "Section",
 CellChangeTimes->{{3.534139828687394*^9, 3.5341398452615843`*^9}, {
  3.534144775282943*^9, 3.534144775694236*^9}, {3.534152310951947*^9, 
  3.5341523294879293`*^9}, {3.585479958037787*^9, 3.5854799904383173`*^9}, {
  3.585480023598304*^9, 3.58548002822314*^9}, {3.585480218772586*^9, 
  3.585480222969017*^9}}],

Cell[BoxData[
 RowBox[{"<<", 
  RowBox[{"StringJoin", "[", 
   RowBox[{
   "PathToScannerSDir", ",", "\"\<ScannerScore/ScannerSInputPackage.m\>\""}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.585657443810758*^9, 3.585657482848139*^9}, {
  3.5856577377167387`*^9, 3.585657792996539*^9}, {3.585657844130536*^9, 
  3.585657845703484*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1029, 691},
WindowMargins->{{91, Automatic}, {Automatic, 0}},
Magnification:>FEPrivate`If[
  FEPrivate`Equal[FEPrivate`$VersionNumber, 6.], 1.25, 1.25 Inherited],
FrontEndVersion->"7.0 for Linux x86 (64-bit) (November 11, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 163, 2, 104, "Title"],
Cell[733, 26, 3234, 81, 560, "Text"],
Cell[CellGroupData[{
Cell[3992, 111, 185, 2, 89, "Section"],
Cell[CellGroupData[{
Cell[4202, 117, 234, 3, 47, "Subsection"],
Cell[4439, 122, 664, 14, 38, "Input"],
Cell[5106, 138, 895, 17, 38, "Input"],
Cell[6004, 157, 2222, 44, 189, "Input"],
Cell[8229, 203, 2228, 42, 214, "Input"],
Cell[10460, 247, 2597, 51, 264, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13094, 303, 320, 5, 47, "Subsection"],
Cell[13417, 310, 248, 5, 61, "Text"],
Cell[CellGroupData[{
Cell[13690, 319, 1092, 25, 38, "Input"],
Cell[14785, 346, 2100, 38, 60, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16922, 389, 1291, 28, 38, "Input"],
Cell[18216, 419, 3211, 54, 60, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21464, 478, 852, 22, 38, "Input"],
Cell[22319, 502, 2062, 38, 60, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24418, 545, 759, 20, 38, "Input"],
Cell[25180, 567, 2478, 44, 60, "Output"]
}, Open  ]],
Cell[27673, 614, 256, 5, 61, "Text"],
Cell[CellGroupData[{
Cell[27954, 623, 4297, 87, 114, "Input"],
Cell[32254, 712, 20481, 562, 813, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[52784, 1280, 195, 2, 47, "Subsection"],
Cell[52982, 1284, 693, 19, 139, "Input"],
Cell[53678, 1305, 239, 5, 38, "Input"],
Cell[53920, 1312, 461, 11, 64, "Input"],
Cell[54384, 1325, 555, 12, 64, "Input"],
Cell[CellGroupData[{
Cell[54964, 1341, 162, 3, 35, "Subsubsection"],
Cell[55129, 1346, 139, 3, 38, "Input"],
Cell[55271, 1351, 511, 14, 114, "Input"],
Cell[55785, 1367, 507, 11, 64, "Input"],
Cell[56295, 1380, 753, 15, 64, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[57085, 1400, 222, 4, 35, "Subsubsection"],
Cell[57310, 1406, 139, 3, 38, "Input"],
Cell[57452, 1411, 553, 14, 114, "Input"],
Cell[58008, 1427, 507, 11, 64, "Input"],
Cell[58518, 1440, 858, 17, 64, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[59425, 1463, 132, 1, 47, "Subsection"],
Cell[CellGroupData[{
Cell[59582, 1468, 106, 1, 35, "Subsubsection"],
Cell[59691, 1471, 2824, 75, 464, "Input"],
Cell[62518, 1548, 817, 23, 189, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[63372, 1576, 101, 1, 35, "Subsubsection"],
Cell[63476, 1579, 1242, 26, 139, "Input"],
Cell[64721, 1607, 222, 5, 38, "Input"],
Cell[64946, 1614, 391, 7, 38, "Input"],
Cell[65340, 1623, 391, 7, 38, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[65768, 1635, 176, 3, 35, "Subsubsection"],
Cell[65947, 1640, 756, 20, 139, "Input"],
Cell[66706, 1662, 222, 5, 38, "Input"],
Cell[66931, 1669, 823, 16, 64, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[67803, 1691, 177, 2, 47, "Subsection"],
Cell[67983, 1695, 305, 5, 38, "Input"],
Cell[68291, 1702, 338, 8, 64, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[68678, 1716, 403, 7, 89, "Section"],
Cell[69084, 1725, 338, 8, 38, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
